@@ -35,14 +35,15 @@ DBIx::Class::Loader::Writing - Loader subclass writing guide
       my ( $self, $table ) = @_;
       ...
       return ( \@cols, \@primary );
-   }
+  }
 
-   sub _relationships {
+  sub _relationships {
       my $self = shift;
       ...
-      $self->_belongs_to_many($table, $f_key, $f_table);
-          # For each relationship you want to set up
+      $self->_belongs_to_many($table, $f_key, $f_table, $f_column);
+          # For each relationship you want to set up ($f_column is
+          # optional, default is $f_table's primary key)
       ...
-    }
+  }
 
 =cut
